==> amplify_core-0.6.12.tar.gz: lib/src/types/models/model_schema.dart <==
/*
 * Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

library model_schema;

import 'dart:convert';

import 'package:aws_common/aws_common.dart';
import 'package:collection/collection.dart';
import 'package:meta/meta.dart';

import 'auth_rule.dart';
import 'model_field.dart';
import 'model_index.dart';

@immutable
class ModelSchema with AWSEquatable<ModelSchema> {
  final String name;
  final String? pluralName;
  final List<AuthRule>? authRules;
  final Map<String, ModelField>? fields;
  final List<ModelIndex>? indexes;

  const ModelSchema({
    required this.name,
    this.pluralName,
    this.authRules,
    this.fields,
    this.indexes,
  });

  ModelSchema copyWith({
    String? name,
    String? pluralName,
    List<AuthRule>? authRules,
    Map<String, ModelField>? fields,
    List<ModelIndex>? indexes,
  }) {
    return ModelSchema(
      name: name ?? this.name,
      pluralName: pluralName ?? this.pluralName,
      authRules: authRules ?? this.authRules,
      fields: fields ?? this.fields,
      indexes: indexes ?? this.indexes,
    );
  }

  @override
  List<Object?> get props => [
        name,
        pluralName,
        authRules,
        fields,
        indexes,
      ];

  Map<String, Object?> toMap() => {
        'name': name,
        if (pluralName != null) 'pluralName': pluralName,
        if (authRules != null)
          'authRules': authRules?.map((x) => x.toMap()).toList(),
        if (fields != null)
          'fields': fields?.map((key, value) => MapEntry(key, value.toMap())),
        if (indexes != null)
          'indexes': indexes?.map((value) => value.toJson()).toList(),
      };

  factory ModelSchema.fromMap(Map<String, dynamic> map) {
    return ModelSchema(
      name: map['name'],
      pluralName: map['pluralName'],
      authRules: List<AuthRule>.from(map['authRules']?.map(AuthRule.fromMap)),
      fields: Map<String, ModelField>.from(map['fields']),
      indexes: List<ModelIndex>.from(map['indexes']),
    );
  }

  String toJson() => json.encode(toMap());

  factory ModelSchema.fromJson(String source) =>
      ModelSchema.fromMap(json.decode(source));

  @override
  String toString() {
    return 'ModelSchema(name: $name, pluralName: $pluralName, authRules: $authRules, fields: $fields, indexes: $indexes)';
  }
}

==> amplify_core-1.4.0.tar.gz: lib/src/types/models/model_schema.dart <==
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0

import 'dart:convert';

import 'package:amplify_core/src/types/models/auth_rule.dart';
import 'package:amplify_core/src/types/models/model_field.dart';
import 'package:amplify_core/src/types/models/model_index.dart';
import 'package:aws_common/aws_common.dart';
import 'package:meta/meta.dart';

@immutable
class ModelSchema with AWSEquatable<ModelSchema> {
  const ModelSchema({
    required this.name,
    this.pluralName,
    this.authRules,
    this.fields,
    this.indexes,
  });

  final String name;
  final String? pluralName;
  final List<AuthRule>? authRules;
  final Map<String, ModelField>? fields;
  final List<ModelIndex>? indexes;

  ModelSchema copyWith({
    String? name,
    String? pluralName,
    List<AuthRule>? authRules,
    Map<String, ModelField>? fields,
    List<ModelIndex>? indexes,
  }) {
    return ModelSchema(
      name: name ?? this.name,
      pluralName: pluralName ?? this.pluralName,
      authRules: authRules ?? this.authRules,
      fields: fields ?? this.fields,
      indexes: indexes ?? this.indexes,
    );
  }

  @override
  List<Object?> get props => [
        name,
        pluralName,
        authRules,
        fields,
        indexes,
      ];

  Map<String, Object?> toMap() => {
        'name': name,
        if (pluralName != null) 'pluralName': pluralName,
        if (authRules != null)
          'authRules': authRules?.map((x) => x.toMap()).toList(),
        if (fields != null)
          'fields': fields?.map((key, value) => MapEntry(key, value.toMap())),
        if (indexes != null)
          'indexes': indexes?.map((value) => value.toJson()).toList(),
      };

  String toJson() => json.encode(toMap());

  @override
  String toString() {
    return 'ModelSchema(name: $name, pluralName: $pluralName, authRules: $authRules, fields: $fields, indexes: $indexes)';
  }
}
